@@ -83,7 +83,7 @@ r"""
    ⋅- [H] flags:
    ⋅
    ⋅    A flag is a tag already defined (see [I] section).
-   ⋅
+é   ⋅
    ⋅    :flag:          🏴‍☠️ : pirate  # the meaning of 🏴‍☠️ is 'pirate'
    ⋅
    ⋅                           Beware, don't add a comment at the end of a line !
@@ -1310,8 +1310,8 @@ class ETR:
             on the content of .options["read line:xxx")
             ___________________________________________________________________
 
-            ARGUMENTS: TODO
-            o  tlff                  : a TLFF object (line_inttype, line, flags, fals)
+            ARGUMENTS:
+            o  tlff                  : a TLFF object (line_inttype, str_line, flags, fals)
 
             o  (None|dict)details    : (str:str) details about the read line.
                (pimydoc)ETR._read_action():details
